#!/usr/bin/env python
import os
import inspect
from getclass import getclass
from isstring import isstring
from public import public


@public
def objectname(obj, fullname=False):
    """
    return object fullname with dot
    """
    if not obj:
        return
    if isstring(obj):
        obj = os.path.basename(obj).lstrip()
        pos = obj.find("(")
        if pos > 0:
            obj = obj[0:pos]
        pos = obj.find(" ")
        if pos > 0:
            obj = obj[0:pos]
        if not fullname:
            return obj.split(".")[-1]
        return obj
    if isinstance(obj, property):
        cls = getclass(obj)
        for name, member in inspect.getmembers(cls):
            if obj == member:
                if not fullname:
                    return name
                return "%s.%s" % (objectname(cls, fullname=True), name)
    if not hasattr(obj, "__name__"):
        return
    name = obj.__name__
    if inspect.ismodule(obj):
        return objectname(os.path.basename(name), fullname=fullname)
    module = inspect.getmodule(obj)
    if not inspect.isclass(obj):
        cls = getclass(obj)
        if cls and obj != cls and fullname:
            return objectname(cls, fullname=fullname) + "." + name
    if module and fullname:
        return objectname(module, fullname=fullname) + "." + name
    return name
